@@ -22,7 +22,7 @@ BEGIN {
   );
 }
 
-our $VERSION = '2.003000';
+our $VERSION = '2.003001';
 $VERSION = eval $VERSION;
 
 require Moo::sification;
@@ -377,11 +377,11 @@ global and turns the mechanism off entirely so don't put this in library code.
 
 =head1 MOO AND CLASS::XSACCESSOR
 
-If a new enough version of L<Class::XSAccessor> is available, it
-will be used to generate simple accessors, readers, and writers for
-better performance.  Simple accessors are those without lazy defaults,
-type checks/coercions, or triggers.  Readers and writers generated
-by L<Class::XSAccessor> will behave slightly differently: they will
+If a new enough version of L<Class::XSAccessor> is available, it will be used
+to generate simple accessors, readers, and writers for better performance.
+Simple accessors are those without lazy defaults, type checks/coercions, or
+triggers.  Simple readers are those without lazy defaults. Readers and writers
+generated by L<Class::XSAccessor> will behave slightly differently: they will
 reject attempts to call them with the incorrect number of parameters.
 
 =head1 MOO VERSUS ANY::MOOSE
